# twaml

[![builds.sr.ht status](https://builds.sr.ht/~ddavis/twaml.svg)](https://builds.sr.ht/~ddavis/twaml?)
[![CircleCI (all branches)](https://img.shields.io/circleci/project/github/drdavis/twaml.svg?label=circle%20ci)](https://circleci.com/gh/drdavis/twaml)
[![Documentation Status](https://readthedocs.org/projects/twaml/badge/?version=stable)](https://twaml.readthedocs.io/en/stable/?badge=stable)
![](https://img.shields.io/pypi/pyversions/twaml.svg?colorB=blue&style=flat)
[![PyPI version](https://img.shields.io/pypi/v/twaml.svg?colorB=486b87&style=flat)](https://pypi.org/project/twaml/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)

tW Analysis (Machine Learning) python toolkit.
